@@ -1,21 +1,13 @@
 `as.splineMatrix` <- 
 function(matrix_argument,
 	matrix_argument_name,
+	content_area=NULL,
+	year=NULL,
 	sgp_object=NULL) {
 
 		if (!class(matrix_argument) %in% c("matrix", "splineMatrix")) stop("Supplied object must be of class 'matrix' or 'splineMatrix'.")
 		if (class(matrix_argument) == "splineMatrix" && validObject(matrix_argument, test=TRUE)==TRUE) return(matrix_argument)
 
-		### Utility functions
-
-			year.increment <- function(year, increment) {
-				tmp.list <- list()
-				for (i in seq_along(increment)) {
-					tmp.list[[i]] <- paste(as.numeric(unlist(strsplit(as.character(year), "_")))+increment[i], collapse="_")
-				}
-				unlist(tmp.list)
-			}
-
 		### Create relvant variables
 
 			if (class(matrix_argument)=="matrix") tmp.matrix <- matrix_argument else tmp.matrix <- matrix_argument@.Data
@@ -76,21 +68,25 @@ function(matrix_argument,
 
 			### Content Areas
 
-			content_areas <- rep(unlist(strsplit(gsub("'|]]", "", strsplit(rn, "\\[\\[")[[1]][2]), "[.]"))[1], length(grade_progression))
+			content_areas <- rep(unlist(strsplit(gsub("'|]]|\"", "", strsplit(rn, "\\[\\[|\\$")[[1]][2]), "[.]"))[1], length(grade_progression))
 
 
 			### Time Lag
 
-			time_lags <- diff(type.convert(grade_progression))
+			time_lags <- as.integer(diff(type.convert(grade_progression)))
 
 
 			### Time
 
-			tmp.time <- unlist(strsplit(gsub("'|]]", "", strsplit(rn, "\\[\\[")[[1]][2]), "[.]"))[2]
+			tmp.time <- unlist(strsplit(gsub("'|]]|\"", "", strsplit(rn, "\\[\\[|\\$")[[1]][2]), "[.]"))[2]
+			if (!is.null(year) && tmp.time != year) {
+				message("\tNOTE: Year from supplied splineMatrix does not equal year indicated in @SGP[['Coefficient_Matrices']]. Results will proceed based upon @SGP[['Coefficient_Matrices']]")
+				tmp.time <- year
+			}
 			if (tmp.time == "BASELINE") {
 				time <- rep("BASELINE", length(grade_progression))
 			} else {
-				time <- rev(year.increment(tmp.time, -cumsum(c(0, time_lags))))
+				time <- as.character(rev(yearIncrement(tmp.time, -cumsum(c(0, rev(time_lags))))))
 			}
 
 
@@ -139,7 +135,7 @@ function(matrix_argument,
 			if (.hasSlot(matrix_argument, "Content_Areas")) {
 				content_areas <- as.character(matrix_argument@Content_Areas[[1]])
 			} else {
-				content_areas <- rep(unlist(strsplit(gsub("'|]]", "", strsplit(rn, "\\[\\[")[[1]][2]), "[.]"))[1], length(grade_progression))
+				content_areas <- rep(unlist(strsplit(gsub("'|]]|\"", "", strsplit(rn, "\\[\\[|\\$")[[1]][2]), "[.]"))[1], length(grade_progression))
 			}
 
 
@@ -154,14 +150,18 @@ function(matrix_argument,
 
 			### Time
 
-			if (.hasSlot(matrix_argument, "Time")) {
+			if (.hasSlot(matrix_argument, "Time") && matrix_argument@Version[['SGP_Package_Version']] > "1.0.6.0") {
 				time <- as.character(matrix_argument@Time[[1]])
 			} else {
-				tmp.time <- unlist(strsplit(gsub("'|]]", "", strsplit(rn, "\\[\\[")[[1]][2]), "[.]"))[2]
+				tmp.time <- unlist(strsplit(gsub("'|]]|\"", "", strsplit(rn, "\\[\\[|\\$")[[1]][2]), "[.]"))[2]
+				if (!is.null(year) && tmp.time != year) {
+					message("\tNOTE: Year from supplied splineMatrix does not equal year indicated in @SGP[['Coefficient_Matrices']]. Results will proceed based upon @SGP[['Coefficient_Matrices']]")
+					tmp.time <- year
+				}
 				if (tmp.time == "BASELINE") {
 					time <- rep("BASELINE", length(grade_progression))
 				} else {
-					time <- as.character(rev(year.increment(tmp.time, -cumsum(c(0, time_lags)))))
+					time <- as.character(rev(yearIncrement(tmp.time, -cumsum(c(0, rev(time_lags))))))
 				}
 			}
 
