@@ -4,6 +4,14 @@ function(
 	process,
 	qr.taus) {
 	
+	if (any(toupper(parallel.config[['BACKEND']]) == 'MULTICORE' | toupper(parallel.config[['BACKEND']]) == 'SNOW')) {
+		stop(paste('\n\t', parallel.config[['BACKEND']], "no longer supported.  Please use the 'PARALLEL' package backend and R > 2.12 for parallel computation.\n"))
+	}
+	
+	if (toupper(parallel.config[['BACKEND']]) == 'FOREACH' && (parallel.config[['TYPE']] != "doParallel" & !is.na(parallel.config[['TYPE']]))) {
+			stop(paste('\n\t', parallel.config[['TYPE']], "no longer supported.  Please use doParallel and R > 2.12 for parallel computation.\n"))
+	}
+	
 	workers <- NULL; par.type <- 'OTHER'; TAUS.LIST <- NULL
 
 	if (!is.null(parallel.config[['CLUSTER.OBJECT']])) {
@@ -44,19 +52,18 @@ function(
 	
 	if (all(c("PERCENTILES", "TAUS") %in% names(parallel.config[['WORKERS']]))) stop("Both TAUS and PERCENTILES can not be executed in Parallel at the same time.")
 
-	# parallel.config=list(BACKEND="PARALLEL", WORKERS=list(PERCENTILES=8, PROJ=5, BASE=7, TAUS=3))
 	###  Basic configuration
 	
 	if (toupper(parallel.config[['BACKEND']]) == 'FOREACH') {
 		if (!is.na(parallel.config[['TYPE']]) & !identical(parallel.config[['TYPE']], "NA")) {
-			eval(parse(text=paste("require(", parallel.config[['TYPE']], ")")))
-		} else parallel.config[['TYPE']] <- "NA"
+			eval(parse(text=paste("suppressPackageStartupMessages(require(", parallel.config[['TYPE']], "))")))
+		} else parallel.config[['TYPE']] <- "doParallel"
 
-		if (parallel.config[['TYPE']]=="doMC" & is.null(parallel.config[['OPTIONS']][["preschedule"]])) {
-			if (is.list(parallel.config[['OPTIONS']])) {
-				parallel.config[['OPTIONS']][["preschedule"]]=FALSE
-			}	else parallel.config[['OPTIONS']]=list(preschedule=FALSE)
-		}
+		# if (parallel.config[['TYPE']]=="doMC" & is.null(parallel.config[['OPTIONS']][["preschedule"]])) {
+			# if (is.list(parallel.config[['OPTIONS']])) {
+				# parallel.config[['OPTIONS']][["preschedule"]]=FALSE
+			# }	else parallel.config[['OPTIONS']]=list(preschedule=FALSE)
+		# }
 
 		if (parallel.config[['TYPE']]=="doParallel") { 
 			if (.Platform$OS.type == "unix" & is.null(par.type)) par.type <- 'MULTICORE' 
@@ -71,18 +78,18 @@ function(
 		foreach.options <- parallel.config[['OPTIONS']] # works fine if NULL
 	} #  END FOREACH
 
-	if (toupper(parallel.config[['BACKEND']]) == 'MULTICORE') {
-		par.type <- 'MULTICORE'
-	}
+	# if (toupper(parallel.config[['BACKEND']]) == 'MULTICORE') {
+		# par.type <- 'MULTICORE'
+	# }
 
-	if (toupper(parallel.config[['BACKEND']]) == 'SNOW') {
-		par.type <- 'SNOW'
-	}
+	# if (toupper(parallel.config[['BACKEND']]) == 'SNOW') {
+		# par.type <- 'SNOW'
+	# }
 
 	if (toupper(parallel.config[['BACKEND']]) == 'PARALLEL') {
 		# Weird error for MPI stopCluster(...) 'Error in NextMethod() : 'NextMethod' called from an anonymous function'  load snow first removes it.
 		# if (!is.null(parallel.config[['TYPE']]) && parallel.config[['TYPE']] == 'MPI') require(snow)  #  Don't think this is a problem any more... 08/03/12
-		require(parallel)
+		suppressPackageStartupMessages(require(parallel))
 		if (!is.null(parallel.config[['TYPE']])) {
 			if (!parallel.config[['TYPE']] %in% c('SOCK', 'MPI')) {
 				stop("The 'snow' package will be used when 'parallel.config$TYPE' is specified and BACKEND=='PARALLEL'.  List element must be 'SOCK' or 'MPI'.")
@@ -90,7 +97,7 @@ function(
 			par.type <- 'SNOW'
 		} else {
 			if (.Platform$OS.type == "unix") par.type <- 'MULTICORE' 
-			if (.Platform$OS.type != "unix") par.type <- 'SNOW'
+			if (.Platform$OS.type != "unix") par.type <- 'SNOW'; parallel.config[['TYPE']] <- 'SOCK'
 		}
 	}
 	
@@ -112,6 +119,7 @@ function(
 	###
 	###  Need this for all flavors - move to startParallel
 	###
+
 	if (process=='TAUS') {
 		chunk.size <- ceiling(length(qr.taus) / workers)
 		TAUS.LIST <- vector("list", workers)
@@ -133,26 +141,26 @@ function(
 			registerDoSEQ() # prevents warning message
 			return(list(foreach.options=foreach.options, par.type=par.type))
 		}
-		if (parallel.config[['TYPE']]=="doMC") {
-			registerDoMC(workers)
-			return(list(foreach.options=foreach.options, par.type=par.type))
-		}
-		if (parallel.config[['TYPE']]=='doMPI') {
-			doPar.cl <- startMPIcluster(count=workers)
-			registerDoMPI(doPar.cl)
-			return(list(doPar.cl=doPar.cl, foreach.options=foreach.options, par.type=par.type))
-		}
-		if (parallel.config[['TYPE']]=='doRedis') {
-			redisWorker('jobs', port=10187) #  Doesn't seem to work.  Maybe get rid of this option/flavor?
-			registerDoRedis('jobs')
-			startLocalWorkers(n=workers, queue='jobs')
-			return(list(jobs='jobs', foreach.options=foreach.options, par.type=par.type))
-		}
-		if (parallel.config[['TYPE']]=='doSNOW') {
-			doPar.cl=makeCluster(workers, type='SOCK')
-			registerDoSNOW(doPar.cl)
-			return(list(doPar.cl=doPar.cl, foreach.options=foreach.options, par.type=par.type))
-		}
+		# if (parallel.config[['TYPE']]=="doMC") {
+			# registerDoMC(workers)
+			# return(list(foreach.options=foreach.options, par.type=par.type))
+		# }
+		# if (parallel.config[['TYPE']]=='doMPI') {
+			# doPar.cl <- startMPIcluster(count=workers)
+			# registerDoMPI(doPar.cl)
+			# return(list(doPar.cl=doPar.cl, foreach.options=foreach.options, par.type=par.type))
+		# }
+		# if (parallel.config[['TYPE']]=='doRedis') {
+			# redisWorker('jobs', port=10187) #  Doesn't seem to work.  Maybe get rid of this option/flavor?
+			# registerDoRedis('jobs')
+			# startLocalWorkers(n=workers, queue='jobs')
+			# return(list(jobs='jobs', foreach.options=foreach.options, par.type=par.type))
+		# }
+		# if (parallel.config[['TYPE']]=='doSNOW') {
+			# doPar.cl=makeCluster(workers, type='SOCK')
+			# registerDoSNOW(doPar.cl)
+			# return(list(doPar.cl=doPar.cl, foreach.options=foreach.options, par.type=par.type))
+		# }
 		if (parallel.config[['TYPE']]=="doParallel") {
 			if (par.type == 'SNOW') {
 				doPar.cl <- makeCluster(workers, type='SOCK')
